# Generated by Django 2.2.1 on 2019-08-21 02:48

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('api', '0005_auto_20190820_1556'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Message',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('content', models.TextField(verbose_name='Content')),
                ('sent_at', models.DateTimeField(blank=True, null=True, verbose_name='sent at')),
                ('read_at', models.DateTimeField(blank=True, null=True, verbose_name='read at')),
                ('title', models.CharField(blank=True, default='', max_length=10)),
                ('recipient', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='received_dm', to='api.Company', verbose_name='Recipient')),
                ('sender', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='sent_dm', to='api.Company', verbose_name='Sender')),
                ('sender_user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='sent_user_dm', to=settings.AUTH_USER_MODEL, verbose_name='Sender_User')),
            ],
        ),
    ]
